# scheduler/config.py

# Scheduler parameters
FIRST_WEEKDAY = 0               # Monday
FIRST_WEEK_DAY_THRESHOLD = 7    # Day <= 7 => First week
AFTER_HOUR = 19                 # 7 PM or later
TIMEZONE = "America/New_York"   # Configurable timezone